@@ -9,7 +9,7 @@ impl<I: Iterator> ListFn for &mut I {
     fn next(self) -> ListState<Self> {
         match self.next() {
             Option::None => ListState::End(self),
-            Option::Some(first) => ListState::Some(ListSome { first, next: self }),
+            Option::Some(first) => ListState::some(first, self ),
         }
     }
 }
@@ -27,9 +27,9 @@ impl<S: ListFn<End = S>> Iterator for ListIterator<S> {
         let mut result = None;
         take(&mut self.0, |list| match list.next() {
             ListState::End(end) => end,
-            ListState::Some(ListSome { first, next }) => {
-                result = Some(first);
-                next
+            ListState::Some(some) => {
+                result = Some(some.first);
+                some.next
             }
         });
         result
@@ -59,9 +59,9 @@ impl<L: ListFn> Iterator for ListIteratorWrap<L> {
         take(self, |wrap| match wrap {
             ListIteratorWrap::List(list) => match list.next() {
                 ListState::End(end) => ListIteratorWrap::End(end),
-                ListState::Some(ListSome { first, next }) => {
-                    result = Some(first);
-                    ListIteratorWrap::List(next)
+                ListState::Some(some) => {
+                    result = Some(some.first);
+                    ListIteratorWrap::List(some.next)
                 }
             },
             end => end,
